@@ -1,18 +1,25 @@
-# Copyright (c) 2009 by David Golden. All rights reserved.
-# Licensed under terms of Perl itself (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License was distributed with this file or you may obtain a 
-# copy of the License from http://dev.perl.org/licenses/
-
-package CPAN::Testers::Fact::Prereqs;
+# 
+# This file is part of CPAN-Testers-Report
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
+use 5.006;
 use strict;
 use warnings;
+package CPAN::Testers::Fact::Prereqs;
+BEGIN {
+  $CPAN::Testers::Fact::Prereqs::VERSION = '1.999001';
+}
+# ABSTRACT: prerequisites detected in running a CPAN Testers report
+
 use Carp ();
 
-use base 'Metabase::Fact::Hash';
-
-our $VERSION = '1.999';
-$VERSION = eval $VERSION; ## no critic
+use Metabase::Fact::Hash 0.016;
+our @ISA = qw/Metabase::Fact::Hash/;
 
 sub optional_keys { qw/configure_requires requires build_requires/ }
 
@@ -27,12 +34,18 @@ sub validate_content {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 CPAN::Testers::Fact::Prereqs - prerequisites detected in running a CPAN Testers report
 
+=head1 VERSION
+
+version 1.999001
+
 =head1 SYNOPSIS
 
   my $fact = CPAN::Testers::Fact::Prereqs->new(
@@ -51,7 +64,6 @@ CPAN::Testers::Fact::Prereqs - prerequisites detected in running a CPAN Testers
     },
   );
 
-
 =head1 DESCRIPTION
 
 Prerequisites detected.  There are three valid types: configure_requires, requires,
@@ -60,8 +72,11 @@ and build_requires.
 The prerequisite must be a version number or logical comparision as defined in the
 META.yml specification document.
 
+=for Pod::Coverage optional_keys
+
 =head1 USAGE
 
+See L<Metabase::Fact>.
 
 =head1 BUGS
 
@@ -74,27 +89,21 @@ existing test-file that illustrates the bug or desired feature.
 
 =head1 AUTHOR
 
-=over 
-
-=item * David A. Golden (DAGOLDEN)
-
-=back
+  David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009 by David A. Golden
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
 
+__END__
+
+
+
+
