@@ -1,18 +1,25 @@
-# Copyright (c) 2009 by David Golden. All rights reserved.
-# Licensed under terms of Perl itself (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License was distributed with this file or you may obtain a 
-# copy of the License from http://dev.perl.org/licenses/
-
-package CPAN::Testers::Fact::TestSummary;
+# 
+# This file is part of CPAN-Testers-Report
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
+use 5.006;
 use strict;
 use warnings;
+package CPAN::Testers::Fact::TestSummary;
+BEGIN {
+  $CPAN::Testers::Fact::TestSummary::VERSION = '1.999001';
+}
+# ABSTRACT: summary of a CPAN Testers analysis of a distribution
+
 use Carp ();
 
-use base 'Metabase::Fact::Hash';
-
-our $VERSION = '1.999';
-$VERSION = eval $VERSION; ## no critic
+use Metabase::Fact::Hash 0.016;
+our @ISA = qw/Metabase::Fact::Hash/;
 
 sub required_keys { qw/grade osname osversion archname perl_version/ }
 
@@ -40,12 +47,18 @@ sub content_metadata_types {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 CPAN::Testers::Fact::TestSummary - summary of a CPAN Testers analysis of a distribution
 
+=head1 VERSION
+
+version 1.999001
+
 =head1 SYNOPSIS
 
   # assume $tr is an (upgraded) Test::Reporter object
@@ -68,9 +81,14 @@ Summarize CPAN testers run -- this is equivalent to the content of the old
 email Subject line, plus explicit OS name and perl version, which previously had
 to be parsed out of the report
 
+=for Pod::Coverage required_keys
+
 =head1 USAGE
 
-# XXX document valid grades, etc. -- dagolden, 2009-03-30 
+See L<Metabase::Fact>.
+
+Todo:
+  # XXX document valid grades, etc. -- dagolden, 2009-03-30 
 
 =head1 BUGS
 
@@ -83,27 +101,20 @@ existing test-file that illustrates the bug or desired feature.
 
 =head1 AUTHOR
 
-=over 
-
-=item * David A. Golden (DAGOLDEN)
-
-=back
+  David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009 by David A. Golden
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
 
+__END__
+
+
+
